import { annotate } from "./annotate";
function register(container) {
    return function (identifier, dependencies, constraint) {
        if (dependencies === void 0) { dependencies = []; }
        return function (constructor) {
            annotate(constructor, dependencies);
            var binding = container.bind(identifier).to(constructor);
            if (constraint !== undefined) {
                constraint(binding);
            }
        };
    };
}
function registerSelf(container) {
    return function (dependencies, constraint) {
        if (dependencies === void 0) { dependencies = []; }
        return function (constructor) {
            annotate(constructor, dependencies);
            var binding = container.bind(constructor).toSelf();
            if (constraint !== undefined) {
                constraint(binding);
            }
        };
    };
}
function registerConstructor(container) {
    return function (identifier, constraint) { return function (constructor) {
        var binding = container.bind(identifier).toConstructor(constructor);
        if (constraint !== undefined) {
            constraint(binding);
        }
    }; };
}
function registerConstantValue(container) {
    return function (identifier, value, constraint) {
        var binding = container.bind(identifier).toConstantValue(value);
        if (constraint !== undefined) {
            constraint(binding);
        }
    };
}
function registerDynamicValue(container) {
    return function (identifier, func, constraint) {
        var binding = container.bind(identifier).toDynamicValue(func);
        if (constraint !== undefined) {
            constraint(binding);
        }
    };
}
function registerFunction(container) {
    return function (identifier, func, constraint) {
        var binding = container.bind(identifier).toFunction(func);
        if (constraint !== undefined) {
            constraint(binding);
        }
    };
}
function registerAutoFactory(container) {
    return function (factoryIdentifier, serviceIdentifier, constraint) {
        var binding = container.bind(factoryIdentifier).toAutoFactory(serviceIdentifier);
        if (constraint !== undefined) {
            constraint(binding);
        }
    };
}
function registerFactory(container) {
    return function (identifier, factory, constraint) {
        var binding = container.bind(identifier).toFactory(factory);
        if (constraint !== undefined) {
            constraint(binding);
        }
    };
}
function registerProvider(container) {
    return function (identifier, provider, constraint) {
        var binding = container.bind(identifier).toProvider(provider);
        if (constraint !== undefined) {
            constraint(binding);
        }
    };
}
export { register, registerSelf, registerConstantValue, registerDynamicValue, registerConstructor, registerFunction, registerAutoFactory, registerFactory, registerProvider };
