"use strict";
var annotate_1 = require("./annotate");
function register(container) {
    return function (identifier, dependencies, constraint) {
        if (dependencies === void 0) { dependencies = []; }
        return function (constructor) {
            annotate_1.annotate(constructor, dependencies);
            var binding = container.bind(identifier).to(constructor);
            if (constraint !== undefined) {
                constraint(binding);
            }
        };
    };
}
exports.register = register;
function registerSelf(container) {
    return function (dependencies, constraint) {
        if (dependencies === void 0) { dependencies = []; }
        return function (constructor) {
            annotate_1.annotate(constructor, dependencies);
            var binding = container.bind(constructor).toSelf();
            if (constraint !== undefined) {
                constraint(binding);
            }
        };
    };
}
exports.registerSelf = registerSelf;
function registerConstructor(container) {
    return function (identifier, constraint) { return function (constructor) {
        var binding = container.bind(identifier).toConstructor(constructor);
        if (constraint !== undefined) {
            constraint(binding);
        }
    }; };
}
exports.registerConstructor = registerConstructor;
function registerConstantValue(container) {
    return function (identifier, value, constraint) {
        var binding = container.bind(identifier).toConstantValue(value);
        if (constraint !== undefined) {
            constraint(binding);
        }
    };
}
exports.registerConstantValue = registerConstantValue;
function registerDynamicValue(container) {
    return function (identifier, func, constraint) {
        var binding = container.bind(identifier).toDynamicValue(func);
        if (constraint !== undefined) {
            constraint(binding);
        }
    };
}
exports.registerDynamicValue = registerDynamicValue;
function registerFunction(container) {
    return function (identifier, func, constraint) {
        var binding = container.bind(identifier).toFunction(func);
        if (constraint !== undefined) {
            constraint(binding);
        }
    };
}
exports.registerFunction = registerFunction;
function registerAutoFactory(container) {
    return function (factoryIdentifier, serviceIdentifier, constraint) {
        var binding = container.bind(factoryIdentifier).toAutoFactory(serviceIdentifier);
        if (constraint !== undefined) {
            constraint(binding);
        }
    };
}
exports.registerAutoFactory = registerAutoFactory;
function registerFactory(container) {
    return function (identifier, factory, constraint) {
        var binding = container.bind(identifier).toFactory(factory);
        if (constraint !== undefined) {
            constraint(binding);
        }
    };
}
exports.registerFactory = registerFactory;
function registerProvider(container) {
    return function (identifier, provider, constraint) {
        var binding = container.bind(identifier).toProvider(provider);
        if (constraint !== undefined) {
            constraint(binding);
        }
    };
}
exports.registerProvider = registerProvider;
